Package: VedicDateTime
Type: Package
Title: Vedic Calendar System
Version: 0.1.9
Authors@R: c(
    person("Neeraj Dhanraj", "Bokde", , "neerajdhanraj@gmail.com", role = c("aut", "cre", "cph")),
    person("Prajwal Kailasnath", "Patil", , "prajwalpatilcodes@gmail.com", role = "aut"),
    person("Saradindu", "Sengupta", ,"saradindu.mi1@iiitmk.ac.in" ,role = "aut"),
    person("Andrés Elías Feijóo", "Lorenzo", , "Afeijoo@uvigo.gal", role = "aut")
  )
Description: Provides platform for Vedic calendar system having several
    functionalities to facilitate conversion between Gregorian and Vedic
    calendar systems, and helpful in examining its impact in the
    time series analysis domain.
URL: https://www.neerajbokde.in/viggnette/2022-09-05-VedicDateTime
BugReports: https://github.com/prajwalkpatil/VedicDateTime/issues
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.2.3
Depends: R (>= 3.1.0)
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), qpdf, formatR,
        spelling, tinytex
VignetteBuilder: knitr
Imports: swephR
Config/testthat/edition: 3
Language: en-US
NeedsCompilation: no
Packaged: 2023-09-20 04:32:40 UTC; Prajwal Patil
Author: Neeraj Dhanraj Bokde [aut, cre, cph],
  Prajwal Kailasnath Patil [aut],
  Saradindu Sengupta [aut],
  Andrés Elías Feijóo Lorenzo [aut]
Maintainer: Neeraj Dhanraj Bokde <neerajdhanraj@gmail.com>
Repository: CRAN
Date/Publication: 2023-09-20 05:20:02 UTC
Built: R 4.4.0; ; 2024-05-05 02:53:58 UTC; unix
